<?php 

namespace Schaffen\SerasaRemessa\Cnab600;

use Schaffen\SerasaRemessa\Utils\Record;
use Schaffen\SerasaRemessa\Utils\RecordColumn;
use Schaffen\SerasaRemessa\Utils\Util;

class Header extends Record {
    private $code = 0;
    private $sequence = 1;
    private $file_idf = "SERASA-CONVEM04";
    private $send_code;
    private $move_date;
    private $cnpj_key;
    private $cnpj_branch_digit;
    private $phone_ddd;
    private $phone_number;
    private $phone_ext;
    private $contact;
    private $shipping_sequence;
    private $shipping_differential;
    private $logon;


    public function __construct($values) {
        $this->validate($values);
        $this->setValues($values);
        $this->setColumns();
    }

    private function validate($values) {
        // if (!isset($values['']) || !isset($values['']) || !isset($values['']) || !              isset($values['']) || !isset($values[''])
    }

    private function setValues($values) {
        $this->move_date = Util::dateToInt($values['move_date']);
        $this->cnpj_key = $values['cnpj_key'];
        $this->cnpj_branch_digit = $values['cnpj_branch_digit'];
        $this->phone_ddd = $values['phone_ddd'];
        $this->phone_number = $values['phone_number'];
        $this->phone_ext = $values['phone_ext'];
        $this->contact = $values['contact'];
        $this->shipping_sequence = $values['shipping_sequence'];
        $this->shipping_differential = $values['shipping_differential'];
        $this->logon = $values['logon'];
        $this->send_code = $values['send_code'];
    }
    
    private function setColumns() {
        $this->setColumn('code', new RecordColumn($this->code, RecordColumn::TYPE_NUMERIC, 1, 1));
        $this->setColumn('cnpj_key', new RecordColumn($this->cnpj_key, RecordColumn::TYPE_NUMERIC, 2, 9));
        $this->setColumn('move_date', new RecordColumn($this->move_date, RecordColumn::TYPE_NUMERIC, 11, 8));
        $this->setColumn('phone_ddd', new RecordColumn($this->phone_ddd, RecordColumn::TYPE_NUMERIC, 19, 4));
        $this->setColumn('phone_number', new RecordColumn($this->phone_number, RecordColumn::TYPE_NUMERIC, 23, 8));
        $this->setColumn('phone_ext', new RecordColumn($this->phone_ext, RecordColumn::TYPE_NUMERIC, 31, 4));
        $this->setColumn('contact', new RecordColumn($this->contact, RecordColumn::TYPE_ALPHABETICAL, 35, 70));
        $this->setColumn('file_idf', new RecordColumn($this->file_idf, RecordColumn::TYPE_ALPHANUMERIC, 105, 15));
        $this->setColumn('shipping_sequence', new RecordColumn($this->shipping_sequence, RecordColumn::TYPE_NUMERIC, 120, 6));
        $this->setColumn('send_code', new RecordColumn($this->send_code, RecordColumn::TYPE_ALPHABETICAL, 126, 1));
        $this->setColumn('shipping_differential', new RecordColumn($this->shipping_differential,  RecordColumn::TYPE_ALPHANUMERIC, 127, 4));
        $this->setColumn('blank_1', new RecordColumn('', RecordColumn::TYPE_ALPHANUMERIC, 131, 3));
        $this->setColumn('logon', new RecordColumn($this->logon, RecordColumn::TYPE_ALPHANUMERIC, 134, 8));
        $this->setColumn('blank_2', new RecordColumn('', RecordColumn::TYPE_ALPHANUMERIC, 142, 392));
        $this->setColumn('errors_code', new RecordColumn('', RecordColumn::TYPE_ALPHANUMERIC, 534, 60));
        $this->setColumn('sequence', new RecordColumn($this->sequence, RecordColumn::TYPE_NUMERIC, 594, 7));
    }

    public function getMoveDate() {
        return $this->move_date;
    }

    public function getCnpjBranchDigit() {
        return $this->cnpj_branch_digit;
    }
}